pub struct MockPlansApi {
PlansApi_expectations: MockPlansApi_PlansApi,
}Fields
PlansApi_expectations: MockPlansApi_PlansApiImplementations
Sourceimpl MockPlansApi
impl MockPlansApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockPlansApi
impl MockPlansApi
Sourcepub fn expect_get(&mut self) -> &mut Expectation
pub fn expect_get(&mut self) -> &mut Expectation
Create an Expectation for mocking the get method
Create an Expectation for mocking the get_premium_plan method